<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Hash;
class UserController extends Controller
{
    public function index()
    {
        return view('user.dashboard'); // Crie a view resources/views/user/dashboard.blade.php
    }
    public function edit($id)
    {
        $user = User::findOrFail($id); // Obtém o usuário pelo ID
        return view('users.edit', compact('user')); // Retorna a view de edição
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email',
            'password' => 'nullable|string|min:8|confirmed',
            'phone' => 'nullable|string|max:20',
            'cep' => 'nullable|string|max:10',
            'neighborhood' => 'nullable|string|max:255',
            'street' => 'nullable|string|max:255',
            'city' => 'nullable|string|max:255',
            'number' => 'nullable|string|max:10',
            'state' => 'nullable|string|max:10',
            'photo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'role' => 'required|in:user,admin', // Para definir o tipo de usuário
        ]);

        $user = User::findOrFail($id);

        // Atualizar os campos gerais
        $user->name = $request->input('name');
        $user->phone = $request->input('phone');
        $user->cep = $request->input('cep');
        $user->neighborhood = $request->input('neighborhood');
        $user->street = $request->input('street');
        $user->city = $request->input('city');
        $user->number = $request->input('number');
        $user->state = $request->input('state');
        // Alteração de senha (opcional)
        if ($request->filled('password')) {
            $user->password = Hash::make($request->input('password'));
        }

        // Alteração de email com código de verificação
        if ($user->email !== $request->input('email')) {
            $newEmail = $request->input('email');
            $verificationCode = rand(100000, 999999);

            // Enviar email com o código de verificação
            Mail::raw("Seu código de verificação é: $verificationCode", function ($message) use ($newEmail) {
                $message->to($newEmail)->subject('Confirmação de Alteração de Email');
            });

            // Salvar o código e o novo email temporariamente
            $user->email_verification_code = $verificationCode;
            $user->new_email = $newEmail;
        }

        // Upload da foto (opcional)
        if ($request->hasFile('photo')) {
            $image = $request->file('photo');
            $path = $image->store('photos', 'public');
            $user->photo = $path;
        }

        // Alteração de papel (role) permitida apenas para administradores
        if (auth()->user()->is_admin) {
            $user->role = $request->input('role');
        }

        $user->save();

        return redirect()->route('users.edit', $id)->with('success', 'Usuário atualizado com sucesso.');
    }

    // Método para validar o código de verificação e atualizar o email
    public function confirmEmail(Request $request, $id)
    {
        $request->validate([
            'verification_code' => 'required|integer',
        ]);

        $user = User::findOrFail($id);

        if ($user->email_verification_code == $request->input('verification_code')) {
            $user->email = $user->new_email;
            $user->email_verification_code = null; // Limpar o código após a verificação
            $user->new_email = null; // Limpar o novo email temporário
            $user->save();

            return redirect()->route('users.edit', $id)->with('success', 'Email atualizado com sucesso.');
        }

        return back()->withErrors(['verification_code' => 'Código de verificação inválido.']);
    }
// Controller para retornar o endereço
public function getRegisteredAddress(Request $request)
{
    // Supondo que o usuário está autenticado
    $user = Auth::user();

    if ($user) {
        return response()->json([
            'postal_code' => $user->postal_code,
            'address' => $user->address,
            'contact' => $user->contact,
            'city' => $user->city,
            'state' => $user->state,
            'phone_number' => $user->phone_number,
        ]);
    }

    return response()->json(['error' => 'Usuário não encontrado'], 404);
}



public function getAddress()
{
    // Simule o usuário autenticado
    $user = auth()->user();

    if (!$user) {
        return response()->json(['error' => 'Usuário não autenticado'], 401);
    }

    // Supondo que o modelo do usuário tenha os campos de endereço
    return response()->json([
        'postal_code' => $user->cep ?? null,
        'address' => $user->street ?? null,
        'contact' => $user->phone ?? null,
        'city' => $user->city ?? null,
        'state' => $user->state ?? null,
        'phone_number' => $user->phone ?? null,
    ]);
}
}
