<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">

    @vite(['resources/sass/app.scss', 'resources/js/app.js'])
    <title>@yield('title', 'Sistema de Gestão')</title>
    @extends('layouts.css');
    <script src="https://unpkg.com/ionicons@4.5.10-0/dist/ionicons.js"></script>
</head>


<body>
    <nav class="navbar navbar-expand-lg" style="background: rgb(232 179 137)">
        <div class="container-navbar">
            <div class="d-flex justify-content-between w-100">
                <div class="d-flex align-items-center">
                    <!-- Exibe o nome do usuário logado à esquerda -->
                    @if (Auth::check())
                        <span class="navbar-text me-3">Bem-vindo, {{ Auth::user()->name }}</span>
                    @endif
                </div>

                <!-- Logo centralizado -->
                <a class="navbar-brand mx-auto" href="#"><img src="/img/vela.png" class="img-logo"
                        alt="">Velas
                    Aromáticas</a>

                <!-- Toggle Button for Mobile -->
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav"
                    aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>
            </div>

            <!-- Navbar Links -->
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav mx-auto" style="list-style: none;"> <!-- Remove os pontos da lista -->
                    <li class="nav-item">
                        <a class="btn text-bg-warning me-2 {{ request()->routeIs('dashboard') ? 'active' : '' }}"
                            href="{{ route('dashboard') }}">Home</a>
                    </li>

                    <li class="nav-item">
                        <a class="btn text-bg-warning {{ request()->routeIs('products.index') ? 'active' : '' }}"
                            href="{{ route('products.index') }}">Produtos</a>
                    </li>

                    <li class="nav-item">
                        <a class="btn text-bg-warning me-2 {{ request()->routeIs('promocoes') ? 'active' : '' }}"
                            href="{{ route('promocoes') }}">Promoções</a>
                    </li>

                    <li class="nav-item">
                        <a class="btn text-bg-warning me-2 {{ request()->routeIs('contato') ? 'active' : '' }}"
                            href="{{ route('fale_conosco') }}">Contato</a>
                    </li>

                    <!-- Exibe menu de admin se o usuário for um administrador -->
                    @if (Auth::check() && Auth::user()->role === 'admin')
                        <li class="nav-item dropdown">
                            <a class="btn text-bg-warning dropdown-toggle me-2 {{ request()->routeIs('admin.*') ? 'active' : '' }}"
                                href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown"
                                aria-expanded="false">
                                Administrador
                            </a>
                            <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                                <li><a class="dropdown-item {{ request()->routeIs('admin.dashboard') ? 'active' : '' }}"
                                        href="{{ route('admin.dashboard') }}">Painel do Admin</a></li>
                                <li><a class="dropdown-item {{ request()->routeIs('products.create') ? 'active' : '' }}"
                                        href="{{ route('products.create') }}">Cadastrar Produto</a></li>
                                <li><a class="dropdown-item {{ request()->routeIs('admin.accounts') ? 'active' : '' }}"
                                        href="{{ route('admin.accounts') }}">Gerenciar Contas</a></li>
                                <li><a class="dropdown-item {{ request()->routeIs('itens_vendas.index') ? 'active' : '' }}"
                                        href="{{ route('itens_vendas.index') }}">Itens Vendas</a></li>
                                <li><a class="dropdown-item {{ request()->routeIs('promocao') ? 'active' : '' }}"
                                        href="{{ route('promocao') }}">Promoçoes</a></li>
                            </ul>
                        </li>
                    @endif
                </ul>
            </div>


            <div class="d-flex justify-content-end w-100 align-items-center">
                <!-- Barra de Pesquisa -->
                <form class="d-flex me-3">
                    <input class="form-control me-2 search-bar" type="search" placeholder="Buscar produtos..."
                        aria-label="Search">
                    <button class="btn text-bg-success" type="submit">Buscar</button>
                </form>

                <!-- Ícone do Carrinho de Compras -->
                <a href="{{ route('cart.index') }}" class="icon-btn position-relative" title="Carrinho de Compras">
                    <ion-icon name="cart" class="icon-size"></ion-icon>
                    <span class="position-absolute top-0 start-100 translate-middle badge rounded-pill bg-danger">
                        {{ $cartItemCount }}
                    </span>
                </a>

                <!-- Formulário para sair -->
                @if (Auth::check())
                    <li class="nav-item">
                        <form action="{{ route('logout') }}" method="POST" style="display: inline;">
                            @csrf
                            <button type="submit" class="btn btn-outline-success">Sair</button>
                        </form>
                    </li>
                @else
                    <li class="nav-item" style="text-decoration: none;"><a class="btn  text-bg-warning"
                            href="{{ route('login') }}">Entrar</a>
                    </li>
                    <li class="nav-item"><a class="btn  text-bg-warning" href="{{ route('register') }}">Registrar</a>
                    </li>
                @endif
            </div>
        </div>
    </nav>





    @yield('content')
</body>

</html>
