<?php
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\WelcomeController;
use App\Http\Controllers\Admin\AccountController;
use App\Http\Controllers\ContatoController;
use App\Http\Controllers\ItensVendaController;
use App\Http\Controllers\AdminMeiosContatoController;
use App\Models\CartItem;
use App\Models\Product;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\FaleConoscoController;
// Rotas públicas
Route::get('/', [WelcomeController::class, 'index']);

Route::middleware('auth')->group(function () {
    // Rota para o cadastro de produtos (somente autenticados)
    Route::get('/products/create', [ProductController::class, 'create'])->name('products.create');
    Route::post('/products', [ProductController::class, 'store'])->name('products.store');
    Route::get('/admin/dashboard', [AdminController::class, 'dashboard'])->name('admin.dashboard');
    Route::get('/admin/accounts', [AccountController::class, 'showAccountForm'])->name('admin.accounts');
    Route::post('/admin/save-bank-account', [AccountController::class, 'saveBankAccount'])->name('admin.saveBankAccount');
    Route::post('/admin/save-pix', [AccountController::class, 'savePix'])->name('admin.savePix');

});

// Rota exclusiva para administradores
Route::middleware(['auth', 'admin'])->group(function () {

});


Route::post('/logout', function () {
    Auth::logout();
    return redirect('/');
})->name('logout');


Route::get('/products', function () {
    $products = Product::all(); // Obtém todos os produtos do banco de dados
    return view('products.index', compact('products')); // Passa os produtos para a view
})->name('products.index');
Route::post('/cart/add/{product}', [CartController::class, 'add'])->name('cart.add');
Route::middleware('auth')->group(function () {
    Route::get('/cart', [CartController::class, 'index'])->name('cart.index');

    // routes/web.php
Route::get('/client-area', [CartController::class, 'clientArea'])->name('client.area');
Route::post('/client-area/finalize-order', [CartController::class, 'finalizeOrder'])->name('client.finalize');
Route::post('/checkout', [CartController::class, 'store'])->name('cart.checkout.store');
Route::put('/cart/{id}/update-status', [CartController::class, 'updateStatus'])->name('cart.updateStatus');
Route::post('/cart/{id}/upload-proof', [CartController::class, 'uploadProof'])->name('cart.uploadProof');

// admin
Route::get('/admin/dashboard', [AdminController::class, 'dashboard'])->name('admin.dashboard');

// Rota para atualizar o status do pedido
Route::put('/admin/checkout/{id}/updateStatus', [AdminController::class, 'updateStatus'])->name('admin.updateStatus');

// Rota para atualizar o usuário do pedido
Route::put('/admin/checkout/{id}/updateUser', [AdminController::class, 'updateUser'])->name('admin.updateUser');
Route::put('admin/checkout/{id}/update-products', [AdminController::class, 'updateProducts'])->name('admin.updateProducts');

Route::get('/itens_venda', [ProductController::class, 'index'])->name('products.index');
Route::get('/itens_venda', [ItensVendaController::class, 'index'])->name('itens_venda.index');
// Rota para listar os produtos
Route::get('/itens_venda', [ItensVendaController::class, 'index'])->name('itens_venda.index');

// Rota para editar um produto
Route::get('/itens-venda/{id}/edit', [ItensVendaController::class, 'edit'])->name('itens_venda.edit');
Route::put('/itens-venda/{id}/update', [ItensVendaController::class, 'update'])->name('itens_venda.update');


// Rota para desativar um produto
Route::put('/itens_venda/{product}/deactivate', [ItensVendaController::class, 'deactivate'])->name('itens_venda.deactivate');
Route::get('/itens_venda', [ItensVendaController::class, 'index'])->name('itens_vendas.index');

Route::get('/accounts', [AccountController::class, 'index'])->name('accounts.index');
    Route::get('/accounts/{id}/edit', [AccountController::class, 'edit'])->name('accounts.edit'); // Aqui está a rota para editar
    Route::put('/accounts/{id}', [AccountController::class, 'update'])->name('accounts.update');
    Route::delete('/accounts/{id}', [AccountController::class, 'destroy'])->name('accounts.destroy');
    Route::get('/mensagens', [ContatoController::class, 'listarMensagens'])->name('admin.mensagens.index');
    Route::get('/meios-contato', [AdminMeiosContatoController::class, 'index'])->name('admin.meios_contato.index');
    Route::get('/meios-contato/create', [AdminMeiosContatoController::class, 'create'])->name('admin.meios_contato.create');
    Route::post('/meios-contato', [AdminMeiosContatoController::class, 'store'])->name('admin.meios_contato.store');
    Route::get('/meios-contato/{id}/edit', [AdminMeiosContatoController::class, 'edit'])->name('admin.meios_contato.edit');
    Route::put('/meios-contato/{id}', [AdminMeiosContatoController::class, 'update'])->name('admin.meios_contato.update');
    Route::delete('/meios-contato/{id}', [AdminMeiosContatoController::class, 'destroy'])->name('admin.meios_contato.destroy');
    Route::get('/promocao', [ProductController::class, 'promocao'])->name('promocao');
    Route::post('/promocao/atualizar', [ProductController::class, 'atualizarPromocao'])->name('promocao.atualizar');

Route::put('/products/{id}/deactivate', [ProductController::class, 'deactivate'])->name('products.deactivate');
Route::get('/products/{id}/edit', [ProductController::class, 'edit'])->name('products.edit');
Route::delete('/cart/remove/{id}', [CartController::class, 'remove'])->name('cart.remove');
Route::get('/users/{id}/edit', [UserController::class, 'edit'])->name('users.edit'); // Página de edição
Route::put('/users/{id}', [UserController::class, 'update'])->name('users.update'); // Atualizar usuário
Route::delete('/users/{id}', [UserController::class, 'destroy'])->name('users.destroy'); // Excluir usuário

Route::put('/users/{id}/confirm-email', [UserController::class, 'confirmEmail'])->name('users.confirm-email');
Route::get('/user/address', [UserController::class, 'getAddress'])->name('user.address');
Route::get('/fale-conosco', [ContatoController::class, 'index'])->name('fale_conosco');
Route::post('/fale-conosco/enviar', [ContatoController::class, 'enviar'])->name('contato.enviar');
Route::get('/area-cliente', [UserController::class, 'areaCliente'])->name('area.cliente');
Route::get('/orders/{orderCode}/items', function ($orderCode) {
    $items = CartItem::where('order_code', $orderCode)->get();

    return response()->json($items);
});
Route::put('/admin/orders/{id}/value', [AdminController::class, 'updateOrderValue'])->name('admin.updateOrderValue');

});
Route::get('/client-area', [CartController::class, 'clientArea'])->name('client.area');
Route::get('/promocoes', [ProductController::class, 'promocoes'])->name('promocoes');


Route::post('/cart/update', [CartController::class, 'update'])->name('cart.update');

Route::get('/checkout', [CartController::class, 'checkout'])->name('cart.checkout');
// Em routes/web.php
Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');